@@ -6,11 +6,12 @@ import json
 from pathlib import Path
 
 from blight.action import Action
+from blight.tool import Tool
 from blight.util import flock_append
 
 
 class Record(Action):
-    def after_run(self, tool, run_skipped):
+    def after_run(self, tool: Tool, *, run_skipped: bool = False):
         record_file = Path(self._config["output"])
 
         # TODO(ww): Restructure this dictionary; it should be more like:
